@@ -1,4 +1,4 @@
-# frozen_string_literal: false
+# frozen_string_literal: true
 require 'rubygems/test_case'
 require 'rubygems/dependency_list'
 
@@ -7,22 +7,30 @@ class TestGemDependencyList < Gem::TestCase
   def setup
     super
 
-    util_clear_gems
-
     @deplist = Gem::DependencyList.new
 
-    # TODO: switch to new_spec
+    # TODO: switch to util_spec
     @a1 = util_spec 'a', '1'
     @a2 = util_spec 'a', '2'
     @a3 = util_spec 'a', '3'
 
-    @b1 = util_spec 'b', '1' do |s| s.add_dependency 'a', '>= 1' end
-    @b2 = util_spec 'b', '2' do |s| s.add_dependency 'a', '>= 1' end
+    @b1 = util_spec 'b', '1' do |s|
+      s.add_dependency 'a', '>= 1'
+    end
+
+    @b2 = util_spec 'b', '2' do |s|
+      s.add_dependency 'a', '>= 1'
+    end
+
+    @c1 = util_spec 'c', '1' do |s|
+      s.add_dependency 'b', '>= 1'
+    end
 
-    @c1 = util_spec 'c', '1' do |s| s.add_dependency 'b', '>= 1' end
     @c2 = util_spec 'c', '2'
 
-    @d1 = util_spec 'd', '1' do |s| s.add_dependency 'c', '>= 1' end
+    @d1 = util_spec 'd', '1' do |s|
+      s.add_dependency 'c', '>= 1'
+    end
   end
 
   def test_active_count
@@ -114,8 +122,6 @@ class TestGemDependencyList < Gem::TestCase
   end
 
   def test_ok_eh
-    util_clear_gems
-
     assert @deplist.ok?, 'no dependencies'
 
     @deplist.add @b2
@@ -128,29 +134,27 @@ class TestGemDependencyList < Gem::TestCase
   end
 
   def test_why_not_ok_eh
-    util_clear_gems
-
     assert_equal({},  @deplist.why_not_ok?)
 
     @deplist.add @b2
 
     exp = {
       "b" => [
-              Gem::Dependency.new("a", ">= 1")
-             ]
+        Gem::Dependency.new("a", ">= 1")
+      ]
     }
 
     assert_equal exp, @deplist.why_not_ok?
   end
 
   def test_why_not_ok_eh_old_dependency
-    a  = new_spec 'a', '1',
+    a  = util_spec 'a', '1',
                   'b' => '~> 1.0'
 
-    b0 = new_spec 'b', '1.0',
+    b0 = util_spec 'b', '1.0',
                   'd' => '>= 0'
 
-    b1 = new_spec 'b', '1.1'
+    b1 = util_spec 'b', '1.1'
 
     util_clear_gems
 
@@ -165,8 +169,13 @@ class TestGemDependencyList < Gem::TestCase
     a1 = util_spec 'a', '1'
     a2 = util_spec 'a', '2'
 
-    b = util_spec 'b', '1' do |s| s.add_dependency 'a', '= 1' end
-    c = util_spec 'c', '1' do |s| s.add_dependency 'a', '= 2' end
+    b = util_spec 'b', '1' do |s|
+      s.add_dependency 'a', '= 1'
+    end
+
+    c = util_spec 'c', '1' do |s|
+      s.add_dependency 'a', '= 2'
+    end
 
     d = util_spec 'd', '1' do |s|
       s.add_dependency 'b'
@@ -214,8 +223,6 @@ class TestGemDependencyList < Gem::TestCase
   end
 
   def test_remove_by_name
-    util_clear_gems
-
     @deplist.add @a1, @b2
 
     @deplist.remove_by_name "a-1"
@@ -257,4 +264,3 @@ class TestGemDependencyList < Gem::TestCase
   end
 
 end
-
